@@ -3,6 +3,7 @@ import click
 from jinja2 import Environment, PackageLoader
 
 import shutil
+import logging
 from pathlib import Path
 
 
@@ -32,7 +33,7 @@ def create_templates_directory(
     "--base-directory", default="./", help="starting directory for your project"
 )
 @click.option(
-    "--static-directory", default="static", help="static directory for your project"
+    "--static-directory", default="./static", help="static directory for your project"
 )
 @click.option(
     "--content-directory", default="./content/pages", help="content directory for your project"
@@ -91,23 +92,30 @@ def quickstart(
 
     click.echo('Initiating Quickstart')
 
-    if static_path:
-        Path(base_directory).joinpath(static_directory).mkdir(
-            parents=True, exist_ok=True
+    if static_path and not (static_dir:=Path(static_directory)).exists():
+        static_dir.mkdir(parents=True)
+
+    else:
+        logging.warning(f'{static_dir=} already exists. Skipping.')
+
+    if content_path and not (content_dir:=Path(content_directory)).exists():
+        content_dir.mkdir(
+            parents=True,
         )
 
-    if content_path:
-        Path(base_directory).joinpath(content_directory).mkdir(
-            parents=True, exist_ok=True
-        )
+    else:
+        logging.warning(f'{content_dir=} already exists. Skipping.')
 
     if templates_path:
         create_templates_directory(
             base_directory, templates_directory, templates_files
         )
 
+    if not Path('./run.py').exists():
+        shutil.copy(
+                Path(render_engine.__file__).parent.joinpath(
+                        'run_template.txt'),
+                        './run.py')
 
-    shutil.copy(
-            Path(render_engine.__file__).parent.joinpath(
-                    'run_template.txt'),
-                    './run.py')
+    else:
+        logging.warning(f'run.py already exists. Skipping.')
