@@ -138,6 +138,7 @@ class Site:
         """
         collection = collection_cls()
         self.collections.update({collection.__class__.__name__: collection})
+        setattr(self, collection.title, collection)
 
         for page in collection.pages:
             self.route(cls=page)
@@ -148,11 +149,11 @@ class Site:
         subcollections = get_subcollections(collection)
 
         for attr, attrval in subcollections:
-            if attr not in self.subcollections.keys():
-                self.subcollections[attr] = [attrval]
+            if attr in self.subcollections.keys():
+                self.subcollections[attr].append(attrval)
 
             else:
-                self.subcollections[attr].append(attrval)
+                self.subcollections[attr] = [attrval]
 
             self.route(Collection.from_subcollection(
                     collection,
